(re-render? form)Does the form need to be re-rendered (e.g., a wizard?)
Does the form need to be re-rendered (e.g., a wizard?)
(reset-form! form)(reset-form! form data)Reset the form to initial state
Reset the form to initial state
(valid? v)Helper function for checking validity of the sub ::on-valid. Accepts a form, subscription or value
Helper function for checking validity of the sub ::on-valid. Accepts a form, subscription or value
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |