ez-wire.form.protocols


IValidateclj/sprotocol

get-affected-fieldsclj/s

(get-affected-fields validation)

Get any fields that might be affected by this validation. This can include the same field as the validation is attached to.

Get any fields that might be affected by this validation. This can include the same field as the validation is attached to.

get-error-messageclj/s

(get-error-message validation value form)

Get any error messages for this validation

Get any error messages for this validation

valid?clj/s

(valid? validation value form)

Evaluate if this validation is true given the value

Evaluate if this validation is true given the value
source

cljdoc builds & hosts documentation for Clojure/Script libraries