(render-navigation {:keys [step last-step? first-step? max-steps form button css
button-props]})(render-step {:keys [step step-opts max-steps css] :as data}
form-fn
{:keys [id] :as form}
args)(show-form-fn form-fn {:keys [params form content]})(show-form-fn form-fn current-step {:keys [form] :as args})Show the form with the fn chosen, can send in a new field-ks
Show the form with the fn chosen, can send in a new field-ks
(wizard form-fn)Takes a form-fn (as-table, as-list, etc) and puts into a surrounding wizard if the form is to be rendered as a wizard
Takes a form-fn (as-table, as-list, etc) and puts into a surrounding wizard if the form is to be rendered as a wizard
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |