(lower s)Converts string to all lower-case.
This function works in strictly locale independent way,
if you want a localized version, just use locale-lower
Converts string to all lower-case. This function works in strictly locale independent way, if you want a localized version, just use `locale-lower`
(reagent-native-wrapper? x)Check if x has been wrapped by reagent
Check if x has been wrapped by reagent
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |